@@ -28,8 +28,9 @@
 #define RS_ACTIONDRAWHATCH_H
 
 #include "rs_previewactioninterface.h"
-#include "rs_hatch.h"
 
+struct RS_HatchData;
+class RS_Hatch;
 
 /**
  * This action class can handle user events to draw hatches.
@@ -38,7 +39,7 @@
  */
 class RS_ActionDrawHatch : public RS_PreviewActionInterface {
 	Q_OBJECT
-public:
+
     /**
      * Action States.
      */
@@ -49,22 +50,19 @@ public:
 public:
     RS_ActionDrawHatch(RS_EntityContainer& container,
                       RS_GraphicView& graphicView);
-    ~RS_ActionDrawHatch() = default;
-	
-	static QAction* createGUIAction(RS2::ActionType /*type*/, QObject* /*parent*/);
+	~RS_ActionDrawHatch();
 
-    virtual void init(int status=0);
-    virtual void trigger();
-    virtual void mouseMoveEvent(QMouseEvent* e);
-    virtual void mouseReleaseEvent(QMouseEvent* e);
-    virtual void updateMouseButtonHints();
-    virtual void updateMouseCursor();
+	void init(int status=0) override;
+	void trigger() override;
+	void mouseMoveEvent(QMouseEvent* e) override;
+	void mouseReleaseEvent(QMouseEvent* e) override;
+	void updateMouseButtonHints() override;
+	void updateMouseCursor() override;
 	void setShowArea(bool s);
 
 private:
-    RS_HatchData data;
-	RS_Hatch* hatch;
-    bool m_bShowArea;
+	std::unique_ptr<RS_HatchData> data;
+	bool m_bShowArea{true};
 };
 
 #endif
