@@ -48,12 +48,9 @@ public:
 public:
     RS_ActionInfoTotalLength(RS_EntityContainer& container,
                           RS_GraphicView& graphicView);
-    ~RS_ActionInfoTotalLength() = default;
-	
-	static QAction* createGUIAction(RS2::ActionType /*type*/, QObject* /*parent*/);
 
-    virtual void init(int status=0);
-    virtual void trigger();
+	void init(int status=0) override;
+	void trigger() override;
 };
 
 #endif
