@@ -33,24 +33,26 @@
 #include "rs_line.h"
 #include "rs_coordinateevent.h"
 #include "rs_modification.h"
+#include "rs_preview.h"
 #include "rs_debug.h"
 
+struct RS_ActionModifyMirror::Points {
+	RS_MirrorData data;
+	RS_Vector axisPoint1;
+	RS_Vector axisPoint2;
+};
+
 RS_ActionModifyMirror::RS_ActionModifyMirror(RS_EntityContainer& container,
         RS_GraphicView& graphicView)
         :RS_PreviewActionInterface("Mirror Entities",
 						   container, graphicView)
-		,data(new RS_MirrorData())
+		, pPoints(new Points{})
 {
 	actionType=RS2::ActionModifyMirror;
 }
 
 RS_ActionModifyMirror::~RS_ActionModifyMirror() = default;
 
-QAction* RS_ActionModifyMirror::createGUIAction(RS2::ActionType /*type*/, QObject* /*parent*/) {
-	QAction* action = new QAction(QIcon(":/extui/modifymirror.png"), tr("&Mirror"), NULL);
-    return action;
-}
-
 void RS_ActionModifyMirror::init(int status) {
     RS_ActionInterface::init(status);
 }
@@ -60,11 +62,10 @@ void RS_ActionModifyMirror::trigger() {
     RS_DEBUG->print("RS_ActionModifyMirror::trigger()");
 
     RS_Modification m(*container, graphicView);
-	m.mirror(*data);
+	m.mirror(pPoints->data);
 
-    if (RS_DIALOGFACTORY) {
-        RS_DIALOGFACTORY->updateSelectionWidget(container->countSelected(),container->totalSelectedLength());
-    }
+	RS_DIALOGFACTORY->updateSelectionWidget(
+				container->countSelected(), container->totalSelectedLength());
 }
 
 void RS_ActionModifyMirror::mouseMoveEvent(QMouseEvent* e) {
@@ -76,19 +77,19 @@ void RS_ActionModifyMirror::mouseMoveEvent(QMouseEvent* e) {
         RS_Vector mouse = snapPoint(e);
         switch (getStatus()) {
         case SetAxisPoint1:
-            axisPoint1 = mouse;
+			pPoints->axisPoint1 = mouse;
             break;
 
         case SetAxisPoint2:
-            if (axisPoint1.valid) {
-                axisPoint2 = mouse;
+			if (pPoints->axisPoint1.valid) {
+				pPoints->axisPoint2 = mouse;
 
                 deletePreview();
                 preview->addSelectionFrom(*container);
-                preview->mirror(axisPoint1, axisPoint2);
+				preview->mirror(pPoints->axisPoint1, pPoints->axisPoint2);
 
 				preview->addEntity(new RS_Line{preview.get(),
-											   axisPoint1, axisPoint2});
+											   pPoints->axisPoint1, pPoints->axisPoint2});
 
                 drawPreview();
             }
@@ -122,24 +123,22 @@ void RS_ActionModifyMirror::coordinateEvent(RS_CoordinateEvent* e) {
 
         switch (getStatus()) {
         case SetAxisPoint1:
-            axisPoint1 = mouse;
+			pPoints->axisPoint1 = mouse;
             setStatus(SetAxisPoint2);
                 graphicView->moveRelativeZero(mouse);
             break;
 
         case SetAxisPoint2:
-            axisPoint2 = mouse;
+			pPoints->axisPoint2 = mouse;
             setStatus(ShowDialog);
                 graphicView->moveRelativeZero(mouse);
-            if (RS_DIALOGFACTORY) {
-				if (RS_DIALOGFACTORY->requestMirrorDialog(*data)) {
-					data->axisPoint1 = axisPoint1;
-					data->axisPoint2 = axisPoint2;
+				if (RS_DIALOGFACTORY->requestMirrorDialog(pPoints->data)) {
+					pPoints->data.axisPoint1 = pPoints->axisPoint1;
+					pPoints->data.axisPoint2 = pPoints->axisPoint2;
                     deletePreview();
                     trigger();
                     finish(false);
                 }
-            }
             break;
 
         default:
@@ -148,27 +147,25 @@ void RS_ActionModifyMirror::coordinateEvent(RS_CoordinateEvent* e) {
 }
 
 void RS_ActionModifyMirror::updateMouseButtonHints() {
-    if (RS_DIALOGFACTORY) {
-        switch (getStatus()) {
-            /*case Select:
-                RS_DIALOGFACTORY->updateMouseWidget(tr("Pick entities to move"),
-                                               tr("Cancel"));
-                break;*/
-        case SetAxisPoint1:
-            RS_DIALOGFACTORY->updateMouseWidget(
-                tr("Specify first point of mirror line"),
-                tr("Cancel"));
-            break;
-        case SetAxisPoint2:
-            RS_DIALOGFACTORY->updateMouseWidget(
-                tr("Specify second point of mirror line"),
-                tr("Back"));
-            break;
-        default:
-            RS_DIALOGFACTORY->updateMouseWidget();
-            break;
-        }
-    }
+	switch (getStatus()) {
+	/*case Select:
+				RS_DIALOGFACTORY->updateMouseWidget(tr("Pick entities to move"),
+											   tr("Cancel"));
+				break;*/
+	case SetAxisPoint1:
+		RS_DIALOGFACTORY->updateMouseWidget(
+					tr("Specify first point of mirror line"),
+					tr("Cancel"));
+		break;
+	case SetAxisPoint2:
+		RS_DIALOGFACTORY->updateMouseWidget(
+					tr("Specify second point of mirror line"),
+					tr("Back"));
+		break;
+	default:
+		RS_DIALOGFACTORY->updateMouseWidget();
+		break;
+	}
 }
 
 void RS_ActionModifyMirror::updateMouseCursor() {
