@@ -34,7 +34,12 @@
 #include "rs_commandevent.h"
 #include "rs_coordinateevent.h"
 #include "rs_math.h"
-#include "rs_debug.h"
+#include "rs_preview.h"
+
+struct RS_ActionPrintPreview::Points {
+	RS_Vector v1;
+	RS_Vector v2;
+};
 
 /**
  * Constructor.
@@ -42,25 +47,17 @@
 RS_ActionPrintPreview::RS_ActionPrintPreview(RS_EntityContainer& container,
                                              RS_GraphicView& graphicView)
     :RS_ActionInterface("Print Preview",
-                        container, graphicView), hasOptions(false),scaleFixed(false)
-    ,m_bPaperOffset(false)
+						container, graphicView)
+	, hasOptions(false)
+	, scaleFixed(false)
+	, m_bPaperOffset(false)
+	, pPoints(new Points{})
 {
     showOptions();
 	actionType=RS2::ActionFilePrintPreview;
 }
 
-QAction* RS_ActionPrintPreview::createGUIAction(RS2::ActionType /*type*/, QObject* /*parent*/) {
-    // tr("Print Preview")
-    QAction* action = new QAction(tr("Print Pre&view"), NULL);
-#if QT_VERSION >= 0x040600
-    action->setIcon(QIcon::fromTheme("document-print-preview", QIcon(":/actions/fileprintpreview.png")));
-#else
-    action->setIcon(QIcon(":/actions/fileprintpreview.png"));
-#endif
-    //action->zetStatusTip(tr("Shows a preview of a print"));
-    return action;
-}
-
+RS_ActionPrintPreview::~RS_ActionPrintPreview()=default;
 
 void RS_ActionPrintPreview::init(int status) {
     RS_ActionInterface::init(status);
@@ -70,15 +67,15 @@ void RS_ActionPrintPreview::init(int status) {
 void RS_ActionPrintPreview::mouseMoveEvent(QMouseEvent* e) {
     switch (getStatus()) {
     case Moving:
-        v2 = graphicView->toGraph(e->x(), e->y());
+		pPoints->v2 = graphicView->toGraph(e->x(), e->y());
         if (graphic) {
             RS_Vector pinsbase = graphic->getPaperInsertionBase();
 
             double scale = graphic->getPaperScale();
 
-            graphic->setPaperInsertionBase(pinsbase-v2*scale+v1*scale);
+			graphic->setPaperInsertionBase(pinsbase-pPoints->v2*scale+pPoints->v1*scale);
         }
-        v1 = v2;
+		pPoints->v1 = pPoints->v2;
         graphicView->redraw(RS2::RedrawGrid); // DRAW Grid also draws paper, background items
         break;
 
@@ -93,7 +90,7 @@ void RS_ActionPrintPreview::mousePressEvent(QMouseEvent* e) {
     if (e->button()==Qt::LeftButton) {
         switch (getStatus()) {
         case Neutral:
-            v1 = graphicView->toGraph(e->x(), e->y());
+			pPoints->v1 = graphicView->toGraph(e->x(), e->y());
             setStatus(Moving);
             break;
 
@@ -111,7 +108,6 @@ void RS_ActionPrintPreview::mouseReleaseEvent(QMouseEvent* e) {
         break;
 
     default:
-        RS_DIALOGFACTORY->requestPreviousMenu();
         e->accept();
         break;
     }
@@ -210,14 +206,12 @@ void RS_ActionPrintPreview::resume() {
 
 //printout warning in command widget
 void RS_ActionPrintPreview::printWarning(const QString& s) {
-	if(RS_DIALOGFACTORY){
-        RS_DIALOGFACTORY->commandMessage(s);
-    }
+	RS_DIALOGFACTORY->commandMessage(s);
 }
 
 void RS_ActionPrintPreview::showOptions() {
     RS_ActionInterface::showOptions();
-	if(RS_DIALOGFACTORY && ! isFinished() ) {
+	if (!isFinished()) {
         RS_DIALOGFACTORY->requestOptions(this, true,hasOptions);
         hasOptions=true;
     }
@@ -260,7 +254,7 @@ void RS_ActionPrintPreview::fit() {
                          " Paper is too small for fitting to page\n"
                          "Please set paper size by Menu: Edit->Current Drawing Preferences->Paper");
         //        double f0=graphic->getPaperScale();
-        if( graphic->fitToPage()==false && RS_DIALOGFACTORY){
+		if ( graphic->fitToPage()==false) {
             RS_DIALOGFACTORY->commandMessage(
                         tr("RS_ActionPrintPreview::fit(): Invalid paper size")
                         );
