@@ -50,25 +50,22 @@ public:
     RS_ActionSelectIntersected(RS_EntityContainer& container,
                          RS_GraphicView& graphicView,
                          bool select);
-	~RS_ActionSelectIntersected()=default;
+	~RS_ActionSelectIntersected() override;
 
-	static QAction* createGUIAction(RS2::ActionType type, QObject* /*parent*/);
-
-    virtual void init(int status=0);
+	void init(int status=0) override;
 	
-    virtual void trigger();
+	void trigger() override;
 	
-    virtual void mouseMoveEvent(QMouseEvent* e);
-    virtual void mousePressEvent(QMouseEvent* e);
-    virtual void mouseReleaseEvent(QMouseEvent* e);
+	void mouseMoveEvent(QMouseEvent* e) override;
+	void mousePressEvent(QMouseEvent* e) override;
+	void mouseReleaseEvent(QMouseEvent* e) override;
 	
-    virtual void updateMouseButtonHints();
-    virtual void updateMouseCursor();
+	void updateMouseButtonHints() override;
+	void updateMouseCursor() override;
 
 protected:
-    RS_Vector v1;
-    RS_Vector v2;
-
+	struct Points;
+	std::unique_ptr<Points> pPoints;
     bool select;
 };
 
