@@ -61,8 +61,8 @@ RS_EntityContainer::RS_EntityContainer(RS_EntityContainer* parent,
     : RS_Entity(parent) {
 
     autoDelete=owner;
-    RS_DEBUG->print("RS_EntityContainer::RS_EntityContainer: "
-                    "owner: %d", (int)owner);
+//    RS_DEBUG->print("RS_EntityContainer::RS_EntityContainer: "
+//                    "owner: %d", (int)owner);
 	subContainer = nullptr;
     //autoUpdateBorders = true;
     entIdx = -1;
@@ -157,10 +157,10 @@ void RS_EntityContainer::reparent(RS_EntityContainer* parent) {
  * @param undone true: entity has become invisible.
  *               false: entity has become visible.
  */
-void RS_EntityContainer::undoStateChanged(bool undone) {
+//void RS_EntityContainer::undoStateChanged(bool undone) {
 
-    RS_Entity::undoStateChanged(undone);
-}
+//    RS_Entity::undoStateChanged(undone);
+//}
 
 
 
@@ -596,7 +596,15 @@ void RS_EntityContainer::calculateBorders() {
     //RS_Entity::calculateBorders();
 }
 
-
+//namespace {
+//bool isBoundingBoxValid(RS_Entity* e) {
+//	if (!(e->getMin() && e->getMax())) return false;
+//	if (!(e->getMin().x <= e->getMax().x)) return false;
+//	if (!(e->getMin().y <= e->getMax().y)) return false;
+//	if ((e->getMin() - e->getMax()).magnitude() > RS_MAXDOUBLE) return false;
+//	return true;
+//}
+//}
 
 /**
  * Recalculates the borders of this entity container including
@@ -605,8 +613,8 @@ void RS_EntityContainer::calculateBorders() {
 void RS_EntityContainer::forcedCalculateBorders() {
     //RS_DEBUG->print("RS_EntityContainer::calculateBorders");
 
-	resetBorders();
-	for (RS_Entity* e: entities){
+    resetBorders();
+    for (RS_Entity* e: entities){
 
         //RS_Layer* layer = e->getLayer();
 
@@ -638,8 +646,6 @@ void RS_EntityContainer::forcedCalculateBorders() {
     //RS_Entity::calculateBorders();
 }
 
-
-
 /**
  * Updates all Dimension entities in this container and / or
  * reposition their labels.
@@ -1144,7 +1150,7 @@ RS_Vector RS_EntityContainer::getNearestEndpoint(const RS_Vector& coord,
 	for (RS_Entity* en: entities){
 
 		if (en->isVisible()
-				&& !en->getParent()->ignoredOnModification()
+                && !en->getParent()->ignoredOnModification()
 				){//no end point for Insert, text, Dim
             point = en->getNearestEndpoint(coord, &curDist);
             if (point.valid && curDist<minDist) {
@@ -1181,7 +1187,7 @@ RS_Vector RS_EntityContainer::getNearestEndpoint(const RS_Vector& coord,
 
     unsigned i0=0;
 	for(auto en: entities){
-		if (!en->getParent()->ignoredOnModification() ){//no end point for Insert, text, Dim
+        if (!en->getParent()->ignoredOnModification() ){//no end point for Insert, text, Dim
 //            std::cout<<"find nearest for entity "<<i0<<std::endl;
             point = en->getNearestEndpoint(coord, &curDist);
             if (point.valid && curDist<minDist) {
@@ -1215,7 +1221,7 @@ RS_Vector RS_EntityContainer::getNearestPointOnEntity(const RS_Vector& coord,
 	RS_Entity* en = getNearestEntity(coord, dist, RS2::ResolveNone);
 
 	if (en && en->isVisible()
-			&& !en->getParent()->ignoredOnModification()
+			&& !en->getParent()->ignoredSnap()
 			){
 		point = en->getNearestPointOnEntity(coord, onEntity, dist, entity);
 	}
@@ -1235,7 +1241,7 @@ RS_Vector RS_EntityContainer::getNearestCenter(const RS_Vector& coord,
 	for(auto en: entities){
 
         if (en->isVisible()
-				&& !en->getParent()->ignoredOnModification()
+				&& !en->getParent()->ignoredSnap()
 				){//no center point for spline, text, Dim
             point = en->getNearestCenter(coord, &curDist);
             if (point.valid && curDist<minDist) {
@@ -1265,7 +1271,7 @@ RS_Vector RS_EntityContainer::getNearestMiddle(const RS_Vector& coord,
 	for(auto en: entities){
 
         if (en->isVisible()
-				&& !en->getParent()->ignoredOnModification()
+				&& !en->getParent()->ignoredSnap()
 				){//no midle point for spline, text, Dim
             point = en->getNearestMiddle(coord, &curDist, middlePoints);
             if (point.valid && curDist<minDist) {
@@ -1322,7 +1328,7 @@ RS_Vector RS_EntityContainer::getNearestIntersection(const RS_Vector& coord,
              en = nextEntity(RS2::ResolveAllButTextImage)) {
             if (
                     !en->isVisible()
-					|| en->getParent()->ignoredOnModification()
+					|| en->getParent()->ignoredSnap()
                     ){
                 continue;
             }
@@ -1424,7 +1430,17 @@ double RS_EntityContainer::getDistanceToPoint(const RS_Vector& coord,
 
             RS_DEBUG->print("entity: getDistanceToPoint: OK");
 
-            if (curDist<minDist) {
+			/*
+			 * By using '<=', we will prefer the *last* item in the container if there are multiple
+			 * entities that are *exactly* the same distance away, which should tend to be the one
+			 * drawn most recently, and the one most likely to be visible (as it is also the order
+			 * that the software draws the entities). This makes a difference when one entity is
+			 * drawn directly over top of another, and it's reasonable to assume that humans will
+			 * tend to want to reference entities that they see or have recently drawn as opposed
+			 * to deeper more forgotten and invisible ones...
+			 */
+			if (curDist<=minDist)
+			{
                 switch(level){
                 case RS2::ResolveAll:
                 case RS2::ResolveAllButTextImage:
@@ -1562,8 +1578,10 @@ bool RS_EntityContainer::optimizeContours() {
                 vpEnd=e2->getEndpoint();
                 removeEntity(e2);
                 continue;
-            }
-            QG_DIALOGFACTORY->commandMessage(errMsg.arg(dist).arg(vpTmp.x).arg(vpTmp.y).arg(vpEnd.x).arg(vpEnd.y));
+			}
+			QG_DIALOGFACTORY->commandMessage(
+						errMsg.arg(dist).arg(vpTmp.x).arg(vpTmp.y).arg(vpEnd.x).arg(vpEnd.y)
+						);
             closed=false;
         }
 		if(next && closed){ 			//workaround if next is nullptr
@@ -1583,8 +1601,9 @@ bool RS_EntityContainer::optimizeContours() {
     }
 //    DEBUG_HEADER
     if(vpEnd.valid && vpEnd.squaredTo(vpStart)>1e-8) {
-        if(closed) QG_DIALOGFACTORY->commandMessage(errMsg.arg(vpEnd.distanceTo(vpStart))
-                                         .arg(vpStart.x).arg(vpStart.y).arg(vpEnd.x).arg(vpEnd.y));
+		if(closed)
+			QG_DIALOGFACTORY->commandMessage(errMsg.arg(vpEnd.distanceTo(vpStart))
+											 .arg(vpStart.x).arg(vpStart.y).arg(vpEnd.x).arg(vpEnd.y));
         closed=false;
     }
 //    std::cout<<"RS_EntityContainer::optimizeContours: 5"<<std::endl;
@@ -1746,7 +1765,7 @@ void RS_EntityContainer::draw(RS_Painter* painter, RS_GraphicView* view,
     }
 
 
-	for(auto e: entities){
+    foreach (auto e, entities){
 
         view->drawEntity(painter, e);
     }
@@ -1802,12 +1821,22 @@ bool RS_EntityContainer::ignoredOnModification() const
     case RS2::EntityDimDiametric: /**< Diametric Dimension */
     case RS2::EntityDimAngular:   /**< Angular Dimension */
     case RS2::EntityDimLeader:    /**< Leader Dimension */
+    case RS2::EntityHatch:
         return true;
     default:
         return false;
     }
 }
 
+bool RS_EntityContainer::ignoredSnap() const
+{
+	// issue #652 , disable snap for hatch
+	// TODO, should snapping on hatch be a feature enabled by settings?
+	if (getParent() && getParent()->rtti() == RS2::EntityHatch)
+			return true;
+	return ignoredOnModification();
+}
+
 QList<RS_Entity *>::const_iterator RS_EntityContainer::begin() const
 {
 	return entities.begin();
@@ -1902,3 +1931,7 @@ RS_Entity* RS_EntityContainer::last() const
 	return entities.last();
 }
 
+QList<RS_Entity*> RS_EntityContainer::getEntityList()
+{
+    return entities;
+}
