@@ -24,17 +24,9 @@
 **
 **********************************************************************/
 
-
 #include "rs_undoable.h"
-
 #include "rs_undocycle.h"
 
-//undocycle must be explicitly set
-RS_Undoable::RS_Undoable(RS_Undoable const&) = default;
-RS_Undoable& RS_Undoable::operator = (RS_Undoable const&) = default;
-RS_Undoable::RS_Undoable(RS_Undoable &&) = default;
-RS_Undoable& RS_Undoable::operator = (RS_Undoable &&) = default;
-
 /**
  * Destructor. Makes sure that this undoable is removed from 
  * its undo cycle before it is deleted.
@@ -44,8 +36,6 @@ RS_Undoable::~RS_Undoable() {
         cycle->removeUndoable(this);
 }
 
-
-
 /**
  * Sets the undo cycle this entity is in. This is necessary to
  * make sure the entity can remove itself from the cycle before
@@ -55,8 +45,6 @@ void RS_Undoable::setUndoCycle(RS_UndoCycle* cycle) {
     this->cycle = cycle;
 }
 
-
-
 /**
  * The undoable thing gets activated if it was undone and 
  * deactivated otherwise.
@@ -66,8 +54,6 @@ void RS_Undoable::changeUndoState() {
 	undoStateChanged(isUndone());
 }
 
-
-
 /**
  * Undoes or redoes an undoable.
  */
@@ -80,8 +66,6 @@ void RS_Undoable::setUndoState(bool undone) {
 	undoStateChanged(isUndone());
 }
 
-
-
 /**
  * Is this entity in the Undo memory and not active?
  */
