@@ -35,6 +35,7 @@
 #include "rs_constructionline.h"
 #include "rs_ellipse.h"
 #include "rs_line.h"
+#include "rs_polyline.h"
 #include "lc_quadratic.h"
 #include "lc_splinepoints.h"
 #include "rs_math.h"
@@ -109,12 +110,13 @@ bool RS_Information::isTrimmable(RS_Entity* e1, RS_Entity* e2) {
                     e1->getParent()==e2->getParent()) {
 
                 // in the same polyline
-                RS_EntityContainer* pl = e1->getParent();
+                RS_Polyline* pl = static_cast<RS_Polyline *>(e1->getParent());
                 int idx1 = pl->findEntity(e1);
                 int idx2 = pl->findEntity(e2);
                 RS_DEBUG->print("RS_Information::isTrimmable: "
                                 "idx1: %d, idx2: %d", idx1, idx2);
-                if (abs(idx1-idx2)==1 || abs(idx1-idx2)==int(pl->count()-1)) {
+                if (abs(idx1-idx2)==1 ||
+					(pl->isClosed() && abs(idx1-idx2)==int(pl->count()-1))) {
                     // directly following entities
                     return true;
                 }
@@ -266,8 +268,12 @@ RS_VectorSolutions RS_Information::getIntersection(RS_Entity const* e1,
 		// issue #484 , quadratic intersection solver is not robust enough for quadratic-quadratic
 		// TODO, implement a robust algorithm for quadratic based solvers, and detecting entity type
 		// circles/arcs can be removed
+		auto isArc = [](RS_Entity const* e) {
+			auto type = e->rtti();
+			return type == RS2::EntityCircle || type == RS2::EntityArc;
+		};
 
-		if(e1->rtti()==RS2::EntityCircle && e2->rtti()==RS2::EntityCircle){
+		if(isArc(e1) && isArc(e2)){
 			//use specialized arc-arc intersection solver
 			ret=getIntersectionArcArc(e1, e2);
 		}else{
@@ -584,18 +590,18 @@ RS_VectorSolutions RS_Information::getIntersectionEllipseEllipse(
 
     if( e01->getMinorRadius() < RS_TOLERANCE || e01 -> getRatio()< RS_TOLERANCE) {
         // treate e01 as a line
-		RS_Line *l0=new RS_Line{e1->getParent(), {{-a1,0.}, {a1,0.}}};
-        ret= getIntersectionEllipseLine(l0, e02);
+        RS_Line line{e1->getParent(), {{-a1,0.}, {a1,0.}}};
+        ret= getIntersectionEllipseLine(&line, e02);
         ret.rotate(-shifta1);
         ret.move(-shiftc1);
         return ret;
     }
     if( e02->getMinorRadius() < RS_TOLERANCE || e02 -> getRatio()< RS_TOLERANCE) {
         // treate e02 as a line
-		RS_Line *l0=new RS_Line{e1->getParent(), {{-a2,0.}, {a2,0.}}};
-		l0->rotate({0.,0.}, e02->getAngle());
-        l0->move(e02->getCenter());
-        ret= getIntersectionEllipseLine(l0, e01);
+        RS_Line line{e1->getParent(), {{-a2,0.}, {a2,0.}}};
+        line.rotate({0.,0.}, e02->getAngle());
+        line.move(e02->getCenter());
+        ret = getIntersectionEllipseLine(&line, e01);
         ret.rotate(-shifta1);
         ret.move(-shiftc1);
         return ret;
@@ -646,10 +652,10 @@ RS_VectorSolutions RS_Information::getIntersectionCircleEllipse(RS_Circle* c1,
 	if (!(c1 && e1)) return ret;
 
 	RS_Ellipse const e2{c1->getParent(),
-			c1->getCenter(), {c1->getRadius(),0.},
+			{c1->getCenter(), {c1->getRadius(),0.},
 			1.0,
 			0., 2.*M_PI,
-			false};
+			false}};
 	return getIntersectionEllipseEllipse(e1, &e2);
 }
 
@@ -660,11 +666,11 @@ RS_VectorSolutions RS_Information::getIntersectionArcEllipse(RS_Arc * a1,
         return ret;
 	}
 	RS_Ellipse const e2{a1->getParent(),
-			a1->getCenter(),
+			{a1->getCenter(),
 			{a1->getRadius(), 0.},
 			1.0,
 			a1->getAngle1(), a1->getAngle2(),
-			a1->isReversed()};
+			a1->isReversed()}};
 	return getIntersectionEllipseEllipse(e1, &e2);
 }
 
