@@ -344,7 +344,7 @@ LC_Quadratic::LC_Quadratic(const RS_AtomicEntity* circle0,
         //ellipse
 		double const ratio=sqrt(a*a - f*f)/a;
 		RS_Vector const& majorP=RS_Vector{angle}*a;
-		RS_Ellipse const ellipse{center,majorP,ratio,0.,0.,false};
+		RS_Ellipse const ellipse{nullptr, {center,majorP,ratio,0.,0.,false}};
 		auto const& lc0=ellipse.getQuadratic();
 
         m_mQuad=lc0.getQuad();
@@ -577,8 +577,8 @@ RS_VectorSolutions LC_Quadratic::getIntersection(const LC_Quadratic& l1, const L
     }
     if(valid) return sol;
     ce.clear();
-    ce.push_back(p1->flipXY().getCoefficients());
-    ce.push_back(p2->flipXY().getCoefficients());
+	ce.push_back(p1->getCoefficients());
+	ce.push_back(p2->getCoefficients());
     sol=RS_Math::simultaneousQuadraticSolverFull(ce);
     ret.clear();
 	for(auto const& v: sol){
