@@ -446,8 +446,10 @@ void RS_Modification::paste(const RS_PasteData& data, RS_Graphic* source) {
 		for(RS_Block* b: *blks){
 			if(!b) continue;
 			QString name = b->getName();
-			while (graphic->findBlock(name)) {
-				name=blks->newName(name);
+			while (true) {
+				RS_Block* pb = graphic->findBlock(name);
+				if (!pb) break;
+				name=pb->getBlockList()->newName(name);
 			}
 			blocksDict[b->getName()] = name;
 			b->setName(name);
@@ -680,7 +682,7 @@ bool RS_Modification::splitPolyline(RS_Polyline& polyline,
                 if (pl==pl1) {
                     // Trim endpoint of entity to first vector
                     pl->addVertex(v, 0.0);
-					pl = nullptr;
+//					pl = nullptr;
                 } else {
                     // Trim startpoint of entity to second vector
                     pl = pl2;
@@ -1636,19 +1638,19 @@ bool RS_Modification::scale(RS_ScaleData& data) {
     //non-isotropic scaling, replacing selected circles with ellipses
 				RS_Circle *c=static_cast<RS_Circle*>(ec);
 				ec= new RS_Ellipse{container,
-						c->getCenter(), {c->getRadius(),0.},
+				{c->getCenter(), {c->getRadius(),0.},
 						1.,
-						0., 0., false};
+						0., 0., false}};
             } else if ( ec->rtti() == RS2::EntityArc ) {
     //non-isotropic scaling, replacing selected arcs with ellipses
 				RS_Arc *c=static_cast<RS_Arc*>(ec);
 				ec= new RS_Ellipse{container,
-								   c->getCenter(),
+								   {c->getCenter(),
 								   {c->getRadius(),0.},
 								   1.0,
 								   c->getAngle1(),
 								   c->getAngle2(),
-								   c->isReversed()};
+								   c->isReversed()}};
             }
             }
 			selectedList.push_back(ec);
@@ -2903,7 +2905,7 @@ bool RS_Modification::round(const RS_Vector& coord,
     }
 
     if (document && handleUndo) {
-		if (!isPolyline && !data.trim) {
+		if (!isPolyline && data.trim) {
             document->addUndoable(trimmed1);
             entity1->setUndoState(true);
             document->addUndoable(entity1);
