@@ -52,6 +52,7 @@
 #include "intern/qc_actiongetent.h"
 #include "rs_math.h"
 #include "rs_debug.h"
+// #include <QDebug>
 
 #if QT_VERSION < 0x040500
 #include "emu_qt45.h"
@@ -171,7 +172,7 @@ Plugin_Entity::Plugin_Entity(RS_EntityContainer* parent, enum DPI::ETYPE type){
         break;
     case DPI::ELLIPSE:
 		entity = new RS_Ellipse{parent,
-				{0.,0.}, {0.,0.},0.,0.,0.,false};
+		{{0.,0.}, {0.,0.},0.,0.,0.,false}};
         break;
     case DPI::IMAGE:
         entity = new RS_Image(parent, RS_ImageData());
@@ -765,7 +766,7 @@ Doc_plugin_interface::Doc_plugin_interface(RS_Document *d, RS_GraphicView* gv, Q
 doc(d)
 ,docGr(doc->getGraphic())
 ,gView(gv)
-,mainWidget(parent)
+,main_window(parent)
 ,haveUndo(false){
 }
 
@@ -1243,12 +1244,16 @@ bool Doc_plugin_interface::getPoint(QPointF *point, const QString& mesage,
         gView->setCurrentAction(a);
         if (base) a->setBasepoint(base);
         QEventLoop ev;
-        while ( !a->isCompleted()) {
+        while (!a->isCompleted()) {
             ev.processEvents ();
+            if (!gView->getEventHandler()->hasAction())
+                break;
+        }
+        if (a->isCompleted() && !a->wasCanceled())
+        {
+            a->getPoint(point);
+            status = true;
         }
-        if (a->isCompleted() ){
-        a->getPoint(point);
-        status = true;}
 //RLZ: delete QC_ActionGetPoint. Investigate how to kill only this action
         gView->killAllActions();
     }
@@ -1263,12 +1268,16 @@ Plug_Entity *Doc_plugin_interface::getEnt(const QString& mesage){
         gView->killAllActions();
         gView->setCurrentAction(a);
         QEventLoop ev;
-        while ( !a->isCompleted())
+        while (!a->isCompleted())
         {
             ev.processEvents ();
+            if (!gView->getEventHandler()->hasAction())
+                break;
         }
+        // qDebug() << "getEnt: passed event loop";
     }
     Plug_Entity *e = reinterpret_cast<Plug_Entity*>(a->getSelected(this));
+    // qDebug() << e;
     gView->killAllActions();
     return e;
 }
@@ -1285,7 +1294,10 @@ bool Doc_plugin_interface::getSelect(QList<Plug_Entity *> *sel, const QString& m
         while (!a->isCompleted())
         {
             ev.processEvents ();
+            if (!gView->getEventHandler()->hasAction())
+                break;
         }
+        // qDebug() << "getSelect: passed event loop";
     }
 //    check if a are cancelled by the user issue #349
     RS_EventHandler* eh = gView->getEventHandler();
@@ -1353,9 +1365,9 @@ bool Doc_plugin_interface::getInt(int *num, const QString& mesage, const QString
         tit = title;
 
 #if QT_VERSION < 0x040500
-    int data = emu_qt45_QInputDialog_getInt( mainWidget, tit, msg, 0, -2147483647, 2147483647, 1, &ok);
+    int data = emu_qt45_QInputDialog_getInt(main_window, tit, msg, 0, -2147483647, 2147483647, 1, &ok);
 #else
-    int data = QInputDialog::getInt( mainWidget, tit, msg, 0, -2147483647, 2147483647, 1, &ok);
+    int data = QInputDialog::getInt(main_window, tit, msg, 0, -2147483647, 2147483647, 1, &ok);
 #endif
 
     if (ok)
@@ -1374,7 +1386,7 @@ bool Doc_plugin_interface::getReal(qreal *num, const QString& mesage, const QStr
     else
         tit = title;
 
-    double data = QInputDialog::getDouble( mainWidget, tit, msg, 0, -2147483647, 2147483647, 4, &ok);
+    double data = QInputDialog::getDouble(main_window, tit, msg, 0, -2147483647, 2147483647, 4, &ok);
     if (ok )
         *num = data;
     return ok;
@@ -1391,7 +1403,7 @@ bool Doc_plugin_interface::getString(QString *txt, const QString& mesage, const
     else
         tit = title;
 
-    QString text = QInputDialog::getText( mainWidget, tit,msg, QLineEdit::Normal,
+    QString text = QInputDialog::getText(main_window, tit,msg, QLineEdit::Normal,
                                          QString(), &ok);
     if (ok && !text.isEmpty()) {
         txt->clear();
