@@ -27,18 +27,11 @@
 #ifndef QC_APPLICATIONWINDOW_H
 #define QC_APPLICATIONWINDOW_H
 
-#include <memory>
-#include "qc_mdiwindow.h"
-#include "qg_mainwindowinterface.h"
+#include "mainwindowx.h"
 
-#ifdef RS_SCRIPTING
-#include "qs_scripter.h"
-#include <qsproject.h>
-#endif
-
-#if QT_VERSION < 0x040400
-class QAssistantClient;
-#endif
+#include "rs_pen.h"
+#include "rs_snapper.h"
+#include <QMap>
 
 class QMdiArea;
 class QMdiSubWindow;
@@ -55,56 +48,64 @@ class QG_MouseWidget;
 class QG_SelectionWidget;
 class QG_RecentFiles;
 class QG_PenToolBar;
-class QHelpEngine;
 class QC_PluginInterface;
 class QG_ActiveLayerName;
 class LC_SimpleTests;
+class LC_CustomToolbar;
+class QG_ActionHandler;
+class RS_GraphicView;
+class RS_Document;
+class TwoStackedLabels;
+class LC_ActionGroupManager;
+
+struct LC_Options;
+
+struct DockAreas
+{
+    QAction* left;
+    QAction* right;
+    QAction* top;
+    QAction* bottom;
+    QAction* floating;
+};
 
 /**
  * Main application window. Hold together document, view and controls.
  *
  * @author Andrew Mustun
  */
-class QC_ApplicationWindow: public QMainWindow,
-    public QG_MainWindowInterface
-        {
+class QC_ApplicationWindow: public MainWindowX
+{
     Q_OBJECT
 
 public:
     QC_ApplicationWindow();
     ~QC_ApplicationWindow();
 
-    void initActions();
-    void initMenuBar();
-    void initToolBar();
-    void initStatusBar();
-
     void initSettings();
-        void restoreDocks();
     void storeSettings();
 
-    void initMDI();
-    void initView();
-
     bool queryExit(bool force);
 
-        /** Catch hotkey for giving focus to command line. */
+    /** Catch hotkey for giving focus to command line. */
     virtual void keyPressEvent(QKeyEvent* e);
-    virtual void keyReleaseEvent(QKeyEvent* e);
     void setRedoEnable(bool enable);
     void setUndoEnable(bool enable);
-    void setPreviousZoomEnable(bool enable);
+    bool loadStyleSheet(QString path);
+
+    std::shared_ptr<LC_Options> options;
+
+    QMap<QString, QAction*> a_map;
+    LC_ActionGroupManager* ag_manager;
 
 public slots:
-    virtual void show();
-    void finishSplashScreen();
-        void slotFocus();
+    void relayAction(QAction* q_action);
+    void slotFocus();
     void slotBack();
     void slotKillAllActions();
-    //void slotNext();
     void slotEnter();
     void slotFocusCommandLine();
-        void slotError(const QString& msg);
+    void slotError(const QString& msg);
 
     void slotWindowActivated(int);
     void slotWindowActivated(QMdiSubWindow* w);
@@ -134,6 +135,7 @@ public slots:
      * opens the given file.
      */
     void slotFileOpen(const QString& fileName, RS2::FormatType type);
+    void slotFileOpenRecent(QAction* action);
     /** saves a document */
     void slotFileSave();
     /** saves a document under a different filename*/
@@ -144,10 +146,8 @@ public slots:
     void slotFileExport();
     bool slotFileExport(const QString& name, const QString& format,
                 QSize size, QSize borders, bool black, bool bw=true);
-    /** closes the current file */
-    void slotFileClose();
     /** closing the current file */
-    void slotFileClosing();
+    void slotFileClosing(QC_MDIWindow*);
     /** prints the current file */
     void slotFilePrint(bool printPDF=false);
     void slotFilePrintPDF();
@@ -163,23 +163,12 @@ public slots:
     /** toggle the statusbar */
     void slotViewStatusBar(bool toggle);
 
-    // void slotBlocksEdit();
     void slotOptionsGeneral();
 
     void slotImportBlock();
-    void slotScriptOpenIDE();
-    void slotScriptRun();
-
-        void slotRunStartScript();
-        void slotRunScript();
-        void slotRunScript(const QString& name);
-
-        void slotInsertBlock();
-        void slotInsertBlock(const QString& name);
 
     /** shows an about dlg*/
-    void slotHelpAbout();
-    void slotHelpManual();
+    void showAboutWindow();
 
     /**
      * @brief slotUpdateActiveLayer
@@ -188,7 +177,35 @@ public slots:
     void slotUpdateActiveLayer();
 	void execPlug();
 
-    void goto_wiki();
+    void invokeLinkList();
+
+    void toggleFullscreen(bool checked);
+
+    void setPreviousZoomEnable(bool enable);
+
+    void hideOptions(QC_MDIWindow*);
+
+    void widgetOptionsDialog();
+
+    void modifyCommandTitleBar(Qt::DockWidgetArea area);
+    void reloadStyleSheet();
+
+    void updateGridStatus(const QString&);
+
+    void showDeviceOptions();
+
+    void updateDevice(QString);
+
+    void invokeMenuCreator();
+    void invokeToolbarCreator();
+    void createToolbar(const QString& toolbar_name);
+    void destroyToolbar(const QString& toolbar_name);
+    void destroyMenu(const QString& activator);
+    void unassignMenu(const QString& activator, const QString& menu_name);
+    void assignMenu(const QString& activator, const QString& menu_name);
+    void invokeMenuAssigner(const QString& menu_name);
+    void updateMenu(const QString& menu_name);
+
 
 signals:
     void gridChanged(bool on);
@@ -235,73 +252,31 @@ public:
 	const RS_Document* getDocument() const;
 	RS_Document* getDocument();
 
-        /**
-         * Creates a new document. Implementation from RS_MainWindowInterface.
-         */
+    /**
+     * Creates a new document. Implementation from RS_MainWindowInterface.
+     */
 	void createNewDocument(const QString& fileName = QString::null, RS_Document* doc=nullptr);
 
-    /**
-     * Implementation from QG_MainWindowInterface.
-     *
-     * @return Pointer to this.
-     */
-	const QMainWindow* getMainWindow() const;
-	QMainWindow* getMainWindow();
+    void redrawAll();
+    void updateGrids();
 
-    /**
-     * @return Pointer to action handler. Implementation from QG_MainWindowInterface.
-     */
-	QG_ActionHandler const* getActionHandler() const{
-        return actionHandler;
+    QG_BlockWidget* getBlockWidget(void)
+    {
+        return blockWidget;
     }
-	QG_ActionHandler* getActionHandler(){
-		return actionHandler;
-	}
 
-        //virtual QToolBar* createToolBar(const QString& name);
-        //virtual void addToolBarButton(QToolBar* tb);
-
-    /**
-     * @return Pointer to the qsa object.
-     */
-#ifdef RS_SCRIPTING
-    QSProject* getQSAProject() {
-				if (scripter!=nullptr) {
-                return scripter->getQSAProject();
-                }
-                else {
-						return nullptr;
-                }
+    QG_SnapToolBar* getSnapToolBar(void)
+    {
+        return snapToolBar;
     }
-#endif
 
-        void redrawAll();
-        void updateGrids();
-
-        /**
-         * Implementation from QG_MainWindowInterface.
-         */
-        virtual void setFocus2() {
-                setFocus();
-        }
-        QG_BlockWidget* getBlockWidget(void)
-        {
-            return blockWidget;
-        }
-
-		QG_SnapToolBar* getSnapToolBar(void)
-		{
-			return snapToolBar;
-		}
-
-		QG_SnapToolBar const* getSnapToolBar(void) const
-		{
-			return snapToolBar;
-		}
+    QG_SnapToolBar const* getSnapToolBar(void) const
+    {
+        return snapToolBar;
+    }
 
 protected:
     void closeEvent(QCloseEvent*);
-    virtual void mouseReleaseEvent(QMouseEvent* e);
     //! \{ accept drop files to open
     virtual void dropEvent(QDropEvent* e);
     virtual void dragEnterEvent(QDragEnterEvent * event);
@@ -309,6 +284,8 @@ protected:
 
 private:
 
+    QMenu* createPopupMenu();
+
     QString format_filename_caption(const QString &qstring_in);
     /** Helper function for Menu file -> New & New.... */
 	bool slotFileNewHelper(QString fileName, QC_MDIWindow* w = nullptr);
@@ -319,17 +296,33 @@ private:
      */
     void updateWindowTitle(QWidget* w);
 
+    //Plugin support
+    void loadPlugins();
+    QMenu *findMenu(const QString &searchMenu, const QObjectList thisMenuList, const QString& currentEntry);
+
+    #ifdef LC_DEBUGGING
+        LC_SimpleTests* m_pSimpleTest;
+    #endif
+
     /** Pointer to the application window (this). */
     static QC_ApplicationWindow* appWindow;
     QTimer *autosaveTimer;
 
-    /** MdiArea for MDI */
-    QMdiArea* mdiAreaCAD;
-    QMdiSubWindow* activedMdiSubWindow;
-    bool mdiAreaTab;
+    QG_ActionHandler* actionHandler;
 
-        /** Dialog factory */
-        QC_DialogFactory* dialogFactory;
+    /** MdiArea for MDI */
+    QMdiArea* mdiAreaCAD{nullptr};
+    QMdiSubWindow* activedMdiSubWindow;
+
+    /** Dialog factory */
+    QC_DialogFactory* dialogFactory;
+
+    /** Recent files list */
+	QG_RecentFiles* recentFiles;
+
+    // --- Dockwidgets ---
+    //! toggle actions for the dock areas
+    DockAreas dock_areas;
 
     /** Layer list widget */
     QG_LayerWidget* layerWidget;
@@ -337,19 +330,10 @@ private:
     QG_BlockWidget* blockWidget;
     /** Library browser widget */
     QG_LibraryWidget* libraryWidget;
+    /** Command line */
+    QG_CommandWidget* commandWidget;
 
-    /** Layer list dock widget */
-    QDockWidget* layerDockWindow;
-    /** Block list dock widget */
-    QDockWidget* blockDockWindow;
-    /** Library list dock widget */
-    QDockWidget* libraryDockWindow;
-
-
-        /** Command line */
-        QG_CommandWidget* commandWidget;
-        QDockWidget* commandDockWindow;
-
+    // --- Statusbar ---
     /** Coordinate widget */
     QG_CoordinateWidget* coordinateWidget;
     /** Mouse widget */
@@ -357,71 +341,45 @@ private:
     /** Selection Status */
     QG_SelectionWidget* selectionWidget;
     QG_ActiveLayerName* m_pActiveLayerName;
+    TwoStackedLabels* grid_status;
 
-    /** Option widget for individual tool options */
-    QToolBar* optionWidget;
-
-    /** Recent files list */
-	std::unique_ptr<QG_RecentFiles> recentFiles;
-    QStringList openedFiles;
-
-    /** Action handler. */
-        QG_ActionHandler* actionHandler;
-
-#ifdef RS_SCRIPTING
-        /** Scripting interface. */
-        QS_Scripter* scripter;
-#endif
-
-    QMenu* fileMenu;
+    // --- Menus ---
     QMenu* windowsMenu;
     QMenu* scriptMenu;
     QMenu* helpMenu;
     QMenu* testMenu;
+    QMenu* file_menu;
 
-    QList <QAction*> recentFilesAction;
-    /** the main toolbars */
-    QToolBar* fileToolBar;
-    QToolBar* editToolBar;
-    QToolBar* zoomToolBar;
-    static QAction* previousZoom;
-    static QAction* undoButton;
-    static QAction* redoButton;
-    bool previousZoomEnable;
-    bool undoEnable;
-    bool redoEnable;
-
+    // --- Toolbars ---
     QG_SnapToolBar* snapToolBar;
+    QG_PenToolBar* penToolBar; //!< for selecting the current pen
+    QToolBar* optionWidget; //!< for individual tool options
 
-    // Toolbar for selecting the current pen
-    QG_PenToolBar* penToolBar;
-    // Toolbar for CAD tools
-    QG_CadToolBar* cadToolBar;
-
-#if QT_VERSION < 0x040400
-    QAssistantClient *assistant;
-#else
-    QHelpEngine* helpEngine;
-    QDockWidget *helpWindow;
-#endif // QT_VERSION 0x040400
+    // --- Actions ---
+    QAction* previousZoom;
+    QAction* undoButton;
+    QAction* redoButton;
 
     QAction* scriptOpenIDE;
     QAction* scriptRun;
-
     QAction* helpAboutApp;
-    QAction* helpManual;
 
-    //display "Draft Mode" in window title for draft mode
-    const QString m_qDraftModeTitle;
-#ifdef LC_DEBUGGING
-	LC_SimpleTests* m_pSimpleTest;
-#endif
+    // --- Flags ---
+    bool previousZoomEnable{false};
+    bool undoEnable{false};
+    bool redoEnable{false};
 
-//Plugin support
-    void loadPlugins();
-    QMenu *findMenu(const QString &searchMenu, const QObjectList thisMenuList, const QString& currentEntry);
-	QList<QC_PluginInterface*> loadedPlugins;
+    // --- Lists ---
+    QList<QC_PluginInterface*> loadedPlugins;
+    QList<QAction*> toolbar_view_actions;
+    QList<QAction*> dockwidget_view_actions;
+    QList<QC_MDIWindow*> window_list;
+    QList<QAction*> recentFilesAction;
 
+    QStringList openedFiles;
+
+    // --- Strings ---
+    QString style_sheet_path;
 };
 
 
