@@ -32,26 +32,24 @@
 #else
 # include <QPrinter>
 # include <QPrintDialog>
-#endif 
-#include <QCloseEvent>
+#endif
+
 #include <QApplication>
-#include <QMainWindow>
+#include <QCloseEvent>
 #include <QCursor>
 #include <QMessageBox>
 #include <QFileInfo>
 #include <QMdiArea>
-#include <QMdiSubWindow>
 #include <QPainter>
 
-#include "qc_applicationwindow.h"
 #include "rs_graphic.h"
 #include "rs_settings.h"
 #include "qg_exitdialog.h"
 #include "qg_filedialog.h"
-#include "qc_graphicview.h"
 #include "rs_insert.h"
 #include "rs_mtext.h"
 #include "rs_pen.h"
+#include "qg_graphicview.h"
 #include "rs_debug.h"
 
 int QC_MDIWindow::idCounter = 0;
@@ -61,21 +59,32 @@ int QC_MDIWindow::idCounter = 0;
  *
  * @param doc Pointer to an existing document of NULL if a new
  *   document shall be created for this window.
- * @param parent Parent widget. Usually a workspace.
+ * @param parent An instance of QMdiArea.
  */
-QC_MDIWindow::QC_MDIWindow(RS_Document* doc,
-                           QWidget* parent, Qt::WindowFlags wflags)
-        : QMainWindow(parent, wflags) {
-
+QC_MDIWindow::QC_MDIWindow(RS_Document* doc, QWidget* parent, Qt::WindowFlags wflags)
+                            : QMdiSubWindow(parent, wflags)
+{
     setAttribute(Qt::WA_DeleteOnClose);
-    owner = false;
     cadMdiArea=qobject_cast<QMdiArea*>(parent);
-    forceClosing = false;
-    initDoc(doc);
-    initView();
+
+    if (doc==nullptr) {
+        document = new RS_Graphic();
+        document->newDoc();
+        owner = true;
+    } else {
+        document = doc;
+        owner = false;
+    }
+
+    graphicView = new QG_GraphicView(this, 0, document);
+    graphicView->setObjectName("graphicview");
+
+    connect(graphicView, SIGNAL(previous_zoom_state(bool)),
+            parent->window(), SLOT(setPreviousZoomEnable(bool)));
+
+    setWidget(graphicView);
+
     id = idCounter++;
-    //childWindows.setAutoDelete(false);
-    parentWindow = NULL;
     setSizePolicy(QSizePolicy::Preferred,QSizePolicy::Preferred);
 	if (document) {
 		if (document->getLayerList()) {
@@ -87,12 +96,8 @@ QC_MDIWindow::QC_MDIWindow(RS_Document* doc,
             document->getBlockList()->addListener(graphicView);
         }
     }
-//    setFocusPolicy(Qt::ClickFocus);
-    //showMaximized();
 }
 
-
-
 /**
  * Destructor.
  *
@@ -100,20 +105,9 @@ QC_MDIWindow::QC_MDIWindow(RS_Document* doc,
  */
 QC_MDIWindow::~QC_MDIWindow()
 {
-    //avoid switching to invalid subwindow, bug#3509368
-	auto windows = cadMdiArea->subWindowList();
-	for(auto p: windows){
-		QC_MDIWindow* m = qobject_cast<QC_MDIWindow*>(p->widget());
-		if(m){
-			p->showMaximized();
-			p->raise();
-			cadMdiArea->setActiveSubWindow(p);
-			break;
-		}else{
-			cadMdiArea->removeSubWindow(p);
-		}
-	}
+    RS_DEBUG->print("~QC_MDIWindow");
 	if(!(graphicView && graphicView->isCleanUp())){
+
 		//do not clear layer/block lists, if application is being closed
 
 		if (document->getLayerList()) {
@@ -129,13 +123,10 @@ QC_MDIWindow::~QC_MDIWindow()
 		}
 		document = nullptr;
 	}
-    cadMdiArea->activateNextSubWindow();
-    QMdiSubWindow* subWindow=cadMdiArea->currentSubWindow();
-    QC_ApplicationWindow::getAppWindow()->slotWindowActivated(subWindow);
 }
 
-QC_GraphicView* QC_MDIWindow::getGraphicView() const{
-	return graphicView;
+QG_GraphicView* QC_MDIWindow::getGraphicView() const{
+    return (graphicView) ? graphicView : nullptr;
 }
 
 /** @return Pointer to document */
@@ -228,42 +219,42 @@ QC_MDIWindow* QC_MDIWindow::getPrintPreview() {
  * @param force Disable cancel button (demo versions)
  * @param ask Ask user before closing.
  */
-bool QC_MDIWindow::closeMDI(bool force, bool ask) {
+bool QC_MDIWindow::closeMDI(bool force, bool ask)
+{
+    RS_DEBUG->print("QC_MDIWindow::closeMDI begin");
     // should never happen:
     if (document==NULL) {
         return true;
     }
 
-    QC_ApplicationWindow::getAppWindow()->slotFilePrintPreview(false);
-
     bool ret = false;
 
-	bool isBlock = (parentWindow);
-
     // This is a block and we don't need to ask the user for closing
     //   since it's still available in the parent drawing after closing.
-    if (isBlock) {
+    if (parentWindow)
+    {
         RS_DEBUG->print("  closing block");
-        // tell parent window we're not here anymore.
-		if (parentWindow) {
-            RS_DEBUG->print("    notifying parent about closing this window");
-            parentWindow->removeChildWindow(this);
-        }
-        emit(signalClosing());
+        RS_DEBUG->print("  notifying parent about closing this window");
+        parentWindow->removeChildWindow(this);
+        emit(signalClosing(this));
         ret = true;
     }
 
     // This is a graphic document. ask user for closing.
     else if (!ask || slotFileClose(force)) {
         RS_DEBUG->print("  closing graphic");
-        // close all child windows:
-		for(auto p: childWindows){
-			cadMdiArea->removeSubWindow(p);
-			p->close();
-		}
-		childWindows.clear();
 
-        emit(signalClosing());
+        emit(signalClosing(this));
+
+        if (childWindows.length() > 0)
+        {
+            for(auto p: childWindows)
+            {
+                cadMdiArea->removeSubWindow(p);
+                p->close();
+            }
+		childWindows.clear();
+        }
 
         ret = true;
     }
@@ -283,6 +274,9 @@ bool QC_MDIWindow::closeMDI(bool force, bool ask) {
  */
 void QC_MDIWindow::closeEvent(QCloseEvent* ce) {
 
+    auto view = getGraphicView();
+    view->killAllActions();
+
     RS_DEBUG->print("QC_MDIWindow::closeEvent begin");
     if (forceClosing) {
         ce->accept();
@@ -299,45 +293,6 @@ void QC_MDIWindow::closeEvent(QCloseEvent* ce) {
     RS_DEBUG->print("QC_MDIWindow::closeEvent end");
 }
 
-
-
-/**
- * Init the document.
- *
- * @param type Document type. RS:EntityGraphic or RS2::EntityBlock
- * @param container Entity container to be used as document or NULL
- * if a new document should be created.
- */
-void QC_MDIWindow::initDoc(RS_Document* doc) {
-
-    RS_DEBUG->print("QC_MDIWindow::initDoc()");
-
-    if (doc==NULL) {
-        document = new RS_Graphic();
-        document->newDoc();
-        owner = true;
-    } else {
-        document = doc;
-        owner = false;
-    }
-
-}
-
-
-
-/**
- * Init the view.
- */
-void QC_MDIWindow::initView() {
-    RS_DEBUG->print("QC_MDIWindow::initView()");
-
-    graphicView = new QC_GraphicView(document, this);
-    setCentralWidget(graphicView);
-//    graphicView->setFocus();
-}
-
-
-
 /**
  * Called when the current pen (color, style, width) has changed.
  * Sets the active pen for the document in this MDI window.
@@ -351,7 +306,6 @@ void QC_MDIWindow::slotPenChanged(const RS_Pen& pen) {
 }
 
 
-
 /**
  * Creates a new empty document in this MDI window.
  */
@@ -641,3 +595,10 @@ std::ostream& operator << (std::ostream& os, QC_MDIWindow& w) {
     return os;
 }
 
+/**
+ * Return true if this window has children (QC_MDIWindow).
+ */
+bool QC_MDIWindow::has_children()
+{
+    return !childWindows.isEmpty();
+}
