@@ -28,8 +28,10 @@
 
 #include <QPointF>
 #include <QHash>
-#include <QString>
-#include <QColor>
+#include <QVariant>
+#include<vector>
+//#include <QColor>
+class QString;
 
 namespace DPI {
     //! Vertical alignments.
@@ -63,6 +65,7 @@ namespace DPI {
         INSERT,
         POLYLINE,
         SPLINE,
+		SPLINEPOINTS,
         HATCH,
         DIMLEADER,
         DIMALIGNED,
@@ -103,12 +106,15 @@ namespace DPI {
         STARTANGLE=50,  /*!< double: arc start angle or rotation angle for insert and text */
         ENDANGLE=51,    /*!< double: arc end angle */
         VISIBLE=60,     /*!< int: 1 visible, 0 invisible (reversed from dxf spec, but more logic*/
-        COLOR=62,       /*!< QColor: entity color */
+        COLOR=62,       /*!< int: -1 ByLayer, -2 ByBlock, other 24 bit RGB color: entity color */
         CLOSEPOLY=70,   /*!< int: closed polyline 0=open, 1=closed */
         TXTALIGNH=72,   /*!< enum: horizontal alignment for text */
         TXTALIGNV=73,   /*!< enum: vertical alignment for text */
         REVERSED=291 /*!< bool: true if arc is reversed (clockwise) */
     };
+//Note about 24 bit RGB color:
+//    decimal integer 1632041, in hex 18 E7 29, in RGB dec 24,231,41
+// example red RGB dec 255,0,0; hex FF0000; decimal integer 16711680
 
     enum LineWidth {
         Width00 = 0,       /**< Width 1.  (0.00mm) */
@@ -165,6 +171,10 @@ namespace DPI {
         LineByBlock = -2      /**< Line type defined by block not entity */
     };
 
+    enum EntColor {
+        das,
+    };
+
 }
 
 class Plug_VertexData
@@ -231,6 +241,8 @@ public:
     */
     virtual void move(QPointF offset) = 0;
 
+	virtual void moveRotate(QPointF const& offset, QPointF const& center, double angle)=0;
+
     //! rotate the entity.
     /*!
     *  \param center center of rotation.
@@ -245,6 +257,11 @@ public:
     */
     virtual void scale(QPointF center, QPointF factor) = 0;
 
+    //! Utility: Get color as string.
+    /*!
+    *  \param color color as integer to convert as string.
+    */
+    virtual QString intColor2str(int color) = 0;
 };
 
 //! Interface for comunicate plugins.
@@ -261,7 +278,8 @@ public:
 class Document_Interface
 {
 public:
-    virtual ~Document_Interface() {}
+    Document_Interface() = default;
+    virtual ~Document_Interface() = default;
     //! Force to update the graphic view.
     /*! Force to update the graphic view.
     */
@@ -314,6 +332,26 @@ public:
     */
     virtual void addEllipse(QPointF *start, QPointF *end, qreal ratio, qreal a1, qreal a2) = 0;
 
+    //! Add addLine entity to current document.
+    /*! Add addLine entity to current document with current attributes; polyline is by lines.
+    *  \param points of line segments
+    *  \param closed whether line is closed
+    */
+    virtual void addLines(std::vector<QPointF> const& points, bool closed=false) = 0;
+
+    //! Add polyline entity to current document.
+    /*! Add polyline entity to current document with current attributes.
+    *  \param points polyline points
+    *  \param closed whether polyline is closed
+    */
+    virtual void addPolyline(std::vector<Plug_VertexData> const& points, bool closed=false) = 0;
+    //! Add LC_SplinePoints entity to current document.
+    /*! Add splinepoints entity to current document with current attributes.
+    *  \param points interpolation points
+    *  \param closed whether splinepoints is closed
+    */
+    virtual void addSplinePoints(std::vector<QPointF> const& points, bool closed=false) = 0;
+
     //! Add image entity to current document.
     /*! Add image entity to current document with current attributes.
     *  \param start start point coordinate.
@@ -389,10 +427,11 @@ public:
     */
     virtual bool deleteLayer(QString name) = 0;
 
-    virtual void getCurrentLayerProperties(QColor *c, DPI::LineWidth *w, DPI::LineType *t) = 0;
-    virtual void getCurrentLayerProperties(QColor *c, QString *w, QString *t) = 0;
-    virtual void setCurrentLayerProperties(QColor c, DPI::LineWidth w, DPI::LineType t) = 0;
-    virtual void setCurrentLayerProperties(QColor c, QString w, QString t) = 0;
+    virtual void getCurrentLayerProperties(int *c, DPI::LineWidth *w, DPI::LineType *t) = 0;
+    virtual void getCurrentLayerProperties(int *c, QString *w, QString *t) = 0;
+    virtual void setCurrentLayerProperties(int c, DPI::LineWidth w, DPI::LineType t) = 0;
+	virtual void setCurrentLayerProperties(int c, QString const& w,
+										   QString const& t) = 0;
 
     //! Gets a point.
     /*! Prompt message or an default message to the user asking for a point.
