@@ -48,7 +48,6 @@
 #include "qg_arctangentialoptions.h"
 #include "qg_beveloptions.h"
 #include "qg_blockdialog.h"
-#include "qg_cadtoolbar.h"
 #include "qg_circleoptions.h"
 #include "qg_circletan2options.h"
 #include "qg_commandwidget.h"
@@ -107,7 +106,6 @@
 #include "qg_polylineoptions.h"
 #include "qg_polylineequidistantoptions.h"
 #include "qg_layerwidget.h"
-#include "qg_mainwindowinterface.h"
 #include "rs_actionprintpreview.h"
 #include "rs_blocklist.h"
 #include "qg_polylineequidistantoptions.h"
@@ -140,9 +138,7 @@ QG_DialogFactory::QG_DialogFactory(QWidget* parent, QToolBar* ow)
 	coordinateWidget = nullptr;
 	mouseWidget = nullptr;
 	selectionWidget = nullptr;
-	cadToolBar = nullptr;
 	commandWidget = nullptr;
-	mainWindow = nullptr;
 	polylineEquidistantOptions=nullptr;
 	snapMiddleOptions=nullptr;
 	snapDistOptions=nullptr;
@@ -152,7 +148,6 @@ QG_DialogFactory::QG_DialogFactory(QWidget* parent, QToolBar* ow)
 }
 
 
-
 /**
  * Destructor
  */
@@ -177,20 +172,6 @@ void QG_DialogFactory::requestWarningDialog(const QString& warning) {
                              QMessageBox::Ok);
 }
 
-
-
-/**
- * Requests a new document from the main window.
- */
-RS_GraphicView* QG_DialogFactory::requestNewDocument(const QString& fileName, RS_Document* doc) {
-		if (mainWindow) {
-                mainWindow->createNewDocument(fileName, doc);
-                return mainWindow->getGraphicView();
-        }
-		return nullptr;
-}
-
-
 /**
  * Shows a dialog for adding a layer. Doesn't add the layer.
  * This is up to the caller.
@@ -969,23 +950,25 @@ void QG_DialogFactory::requestArcOptions(RS_ActionInterface* action,
  * Shows a widget for tangential arc options.
  */
 void QG_DialogFactory::requestArcTangentialOptions(RS_ActionInterface* action,
-        bool on, bool update) {
+		bool on, bool /*update*/) {
 
 
 	if (optionWidget) {
 		static QG_ArcTangentialOptions* toolWidget = nullptr;
-		if (toolWidget) {
+		if (toolWidget && !on) {
             delete toolWidget;
 			toolWidget = nullptr;
         }
 		if (on) {
-			toolWidget = new QG_ArcTangentialOptions(optionWidget);
-            optionWidget->addWidget(toolWidget);
-            toolWidget->setAction(action, update);
-            //toolWidget->setData(&data);
-                        toolWidget->show();
+			bool useUpdate = toolWidget;
+			if (!toolWidget) {
+				toolWidget = new QG_ArcTangentialOptions(optionWidget);
+				optionWidget->addWidget(toolWidget);
+			}
+			toolWidget->setAction(action, useUpdate);
+			toolWidget->show();
         }
-            arcTangentialOptions=toolWidget;
+		arcTangentialOptions=toolWidget;
     }
 }
 
@@ -1398,50 +1381,6 @@ void QG_DialogFactory::requestLibraryInsertOptions(RS_ActionInterface* action,
 }
 
 
-
-/**
- * Shows the given toolbar.
- */
-void QG_DialogFactory::requestToolBar(RS2::ToolBarId id) {
-	if (cadToolBar) {
-        cadToolBar->showToolBar(id);
-    }
-}
-
-void QG_DialogFactory::requestPreviousToolBar() {
-	if (cadToolBar) {
-        cadToolBar->showPreviousToolBar(false);
-    }
-}
-
-
-void QG_DialogFactory::resetToolBar() {
-	if (cadToolBar) {
-        cadToolBar->resetToolBar();
-    }
-}
-
-/**
- * Shows the select toolbar with the given action to launch.
- */
-void QG_DialogFactory::requestToolBarSelect(RS_ActionInterface* selectAction,
-        RS2::ActionType nextAction) {
-	if (cadToolBar) {
-        cadToolBar->showToolBarSelect(selectAction, nextAction);
-    }
-}
-
-/**
-  * Show the cad toolbar according to action type
-  * Author: Dongxu Li
-  **/
-void QG_DialogFactory::showCadToolBar(RS2::ActionType actionType) {
-if(cadToolBar){
-    cadToolBar->showCadToolBar(actionType);
-}
-}
-
-
 /**
  * Shows attributes options dialog presenting the given data.
  */
@@ -1794,9 +1733,9 @@ bool QG_DialogFactory::requestHatchDialog(RS_Hatch* hatch) {
     dlg.setHatch(*hatch, true);
     if (dlg.exec()) {
         dlg.updateHatch();
+        dlg.saveSettings();
         return true;
     }
-
     return false;
 }
 
@@ -1834,17 +1773,6 @@ QString QG_DialogFactory::requestFileSaveAsDialog(const QString& caption /* = QS
     return QFileDialog::getSaveFileName(parent, caption, dir, filter, selectedFilter);
 }
 
-/**
- * Back to last menu in cad toolbar.
- */
-void QG_DialogFactory::requestPreviousMenu() {
-	if (cadToolBar) {
-        cadToolBar->showToolBarMain();
-    }
-}
-
-
-
 /**
  * Called whenever the mouse position changed.
  */
