@@ -32,16 +32,17 @@
 
 class QAction;
 class QWidget;
+class QMenu;
 
 /**
  * This class can store recent files in a list.
  */
-class QG_RecentFiles: public QObject {
-
+class QG_RecentFiles: public QObject
+{
 	Q_OBJECT
 
 public:
-	QG_RecentFiles(int number, QWidget* parent = nullptr);
+	QG_RecentFiles(QObject* parent, int number);
 	virtual ~QG_RecentFiles();
 
     void add(const QString& filename);
@@ -59,16 +60,9 @@ public:
 	int getNumber() const;
 
 	int indexOf(const QString& filename) const;
-	void initSettings();
+	void addFiles(QMenu* file_menu);
 	void updateRecentFilesMenu();
 
-private slots:
-	/**
-	* \brief opens a recent file document
-	* @param id File Menu id of the file
-	*/
-	void slotFileOpenRecent();
-
 private:
 	int const number;
 	QStringList files;
