@@ -408,7 +408,7 @@
     <message>
         <location filename="../asciifile/asciifile.cpp" line="260"/>
         <source>2D Point</source>
-        <translation>نقطة ثنائية اﻷبعاد</translation>
+        <translation>نقطتين</translation>
     </message>
     <message>
         <location filename="../asciifile/asciifile.cpp" line="260"/>
@@ -710,7 +710,7 @@
     <message>
         <location filename="../sample/sample.cpp" line="54"/>
         <source>Draw line</source>
-        <translation>خط الرسم</translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../sample/sample.cpp" line="60"/>
@@ -841,9 +841,8 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../plotequation/plot.cpp" line="28"/>
         <source>Draw</source>
-        <translation>رسم</translation>
+        <translation type="obsolete">رسم</translation>
     </message>
 </context>
 <context>
