@@ -213,12 +213,12 @@
     <message>
         <location filename="../list/list.cpp" line="168"/>
         <source>SOLID</source>
-        <translation>СПЛОШНОЙ</translation>
+        <translation>СПЛОШНАЯ</translation>
     </message>
     <message>
         <location filename="../list/list.cpp" line="172"/>
         <source>MTEXT</source>
-        <translation>МНОГОСТРОЧНЫЙ ТЕКСТ</translation>
+        <translation>МТЕКСТ</translation>
     </message>
     <message>
         <location filename="../list/list.cpp" line="175"/>
@@ -243,7 +243,7 @@
     <message>
         <location filename="../list/list.cpp" line="187"/>
         <source>POLYLINE</source>
-        <translation>ЛОМАНАЯ ЛИНИЯ</translation>
+        <translation>ЛОМАНАЯ</translation>
     </message>
     <message>
         <location filename="../list/list.cpp" line="188"/>
@@ -292,32 +292,32 @@
     <message>
         <location filename="../list/list.cpp" line="216"/>
         <source>DIMLEADER</source>
-        <translation>РАЗМЕР-ВЫНОСКА</translation>
+        <translation>ВЫНОСКА</translation>
     </message>
     <message>
         <location filename="../list/list.cpp" line="219"/>
         <source>DIMALIGNED</source>
-        <translation>РАЗМЕР ВЫРАВНЕННЫЙ</translation>
+        <translation>ВЫРАВНЕННЫЙРАЗМЕР</translation>
     </message>
     <message>
         <location filename="../list/list.cpp" line="222"/>
         <source>DIMLINEAR</source>
-        <translation>РАЗМЕР ЛИНЕЙНЫЙ</translation>
+        <translation>ЛИНЕЙНЫЙРАЗМЕР</translation>
     </message>
     <message>
         <location filename="../list/list.cpp" line="225"/>
         <source>DIMRADIAL</source>
-        <translation>РАЗМЕР РАДИАЛЬНЫЙ</translation>
+        <translation>РАДИАЛЬНЫЙРАЗМЕР</translation>
     </message>
     <message>
         <location filename="../list/list.cpp" line="228"/>
         <source>DIMDIAMETRIC</source>
-        <translation>РАЗМЕР ДИАМЕТРАЛЬНЫЙ</translation>
+        <translation>ДИАМЕТРАЛЬНЫЙРАЗМЕР</translation>
     </message>
     <message>
         <location filename="../list/list.cpp" line="231"/>
         <source>DIMANGULAR</source>
-        <translation>РАЗМЕР УГЛОВОЙ</translation>
+        <translation>УГЛОВОЙРАЗМЕР</translation>
     </message>
     <message>
         <location filename="../list/list.cpp" line="234"/>
@@ -849,9 +849,8 @@
         <translation>График (дополнение)</translation>
     </message>
     <message>
-        <location filename="../plotequation/plot.cpp" line="28"/>
         <source>Draw</source>
-        <translation>Построить</translation>
+        <translation type="obsolete">Построить</translation>
     </message>
 </context>
 <context>
